<?php
/*
Plugin Name: Tweet This
Plugin URI: http://richardxthripp.thripp.com/tweet-this
Description: Adds a Post to Twitter bird icon to the top-right of every post and page, with a nice rollover effect. Shortens URLs in advance through <a href="http://th8.us/">Th8.us</a>, eating up only 16 of 140 characters. Customize or disable auto-insertion under Settings > Tweet This.
Author: Richard X. Thripp
Version: 1.1.1
Author URI: http://richardxthripp.thripp.com/
*/

/*
Tweet This is a plugin for WordPress 1.5 - 2.6.2. Also: WordPress MU.
Copyright 2008  Richard X. Thripp  (email : richardxthripp@thripp.com)
Freely released under Version 2 of the GNU General Public License as published
by the Free Software Foundation, or, at your option, any later version.
*/


function get_tweet_this_short_url() {
	global $id;
	$cached_tt_url = get_post_meta($id, 'tweet_this_url', true);
	if($cached_tt_url && $cached_tt_url != "getnew") {
		return $cached_tt_url;
	} else {
		if (get_option('tt_url_service') == "tinyurl") {
			$url = file_get_contents('http://tinyurl.com/api-create.php?url=' . get_permalink());
			}
		elseif (get_option('tt_url_service') == "is.gd") {
			$url = file_get_contents('http://is.gd/api.php?longurl=' . get_permalink());
			}
		elseif (get_option('tt_url_service') == "urlb.at") {
			$url = file_get_contents('http://urlb.at/api/rest/?url=' . urlencode(get_permalink()));
			}
		elseif (get_option('tt_url_service') == "bit.ly") {
			$url = file_get_contents('http://bit.ly/api?url=' . get_permalink());
			}
		elseif (get_option('tt_url_service') == "snurl") {
			$url = file_get_contents('http://snurl.com/site/snip?r=simple&link=' . get_permalink());
			}
		else {
			$url = 'www.' . file_get_contents('http://th8.us/api-tt.php?url=' . get_permalink());
		}
		if ($cached_tt_url == "getnew")
			update_post_meta($id, 'tweet_this_url', $url, 'getnew');
		else add_post_meta($id, 'tweet_this_url', $url, true);
		return $url;
	}
}


function tweet_this_short_url() {
	echo get_tweet_this_short_url();
}


function get_tweet_this_trim_title() {
	$title = get_the_title();
        $title = $title." ";
        $title = substr($title,0,110);
        $title = substr($title,0,strrpos($title,' '));
        if (strlen($title) > 100 && strlen($title) < 115) $title = $title." ...";
	$title = urlencode($title);
        if (get_option('tt_add_title') != "false") return $title;
}


function tweet_this_trim_title() {
	echo get_tweet_this_trim_title();
}


// is_preview doesn't exist in WP 1.5.
function tt_is_preview() {
	if (function_exists('is_preview')) is_preview();
}


function get_tweet_this_url() {
	$url = 'http://twitter.com/home/?status=' .
	get_tweet_this_short_url() . '+' . get_tweet_this_trim_title();
	if (!tt_is_preview()) {
		if (get_option('tt_limit_to_single') == "true") {
			if (is_single() || is_page()) return $url;
			}
		else return $url;
	}
}


function tweet_this_url() {
	echo get_tweet_this_url();
}


function tweet_this_text_link() {
	$link = '<a href="' . get_tweet_this_url() . '" title="Опубликовать в Twitter (' .
	get_tweet_this_short_url() . ')">Отправить в twitter</a>';
	if (!tt_is_preview()) {
		if (get_option('tt_limit_to_single') == "true") {
			if (is_single() || is_page()) echo $link;
			}
		else echo $link;
	}
}


function tweet_this() {
	$icon = '<a class="tweet-this" href="' . get_tweet_this_url() .
	'" title="Опубликовать в Twitter (' . get_tweet_this_short_url() . ')"></a>';
	if (!tt_is_preview()) {
		if (get_option('tt_limit_to_single') == "true") {
			if (is_single() || is_page()) echo $icon;
			}
		else echo $icon;
	}
}


function get_tweet_this_small() {
	$icon = get_option('siteurl') . '/wp-content/plugins/tweet-this/tweet-this-small.png';
	$link = '<a class="tt-small" href="' . get_tweet_this_url() . '" title="Опубликовать в Twitter (' .
	get_tweet_this_short_url() . ')"><img class="nothumb" src="' . $icon . '" alt="[Опубликовать в Twitter]" /> Опубликовать в twitter</a>';
	if (!tt_is_preview()) {
		if (get_option('tt_limit_to_single') == "true") {
			if (is_single() || is_page()) return $link;
			}
		else return $link;
	}
}


function tweet_this_small() {
	echo get_tweet_this_small();
}


function insert_tweet_this($content) {
	if (get_option('tt_small_icon') == 'true')
		$content .= '<p>' . get_tweet_this_small() . '</p>';
	else $content .= tweet_this();
	return $content;
}


function tweet_this_css() {
	$height = '60';
	$width = '60';
	$tweet_image = get_option('siteurl') . '/wp-content/plugins/tweet-this/tweet-this.png';
	if (get_option('tt_small_icon') != "true") {
		echo '<style type="text/css">a.tweet-this{background:url(' .
		$tweet_image . ') no-repeat 0px 0px;height:' .
		$height . 'px;width:' .
		$width . 'px;float:right;padding-right:5px;margin:19px 5px 5px 10px;} a.tweet-this:hover{background:url(' .
		$tweet_image . ') no-repeat 0px -60px;height:' .
		$height . 'px;width:' .
		$width . 'px;float:right;padding-right:5px;margin:19px 5px 5px 10px;}</style>';
	}
}


// Should be more efficient and compact.
function update_tt_options() {
	$ok = false;
	if ($_REQUEST['tt_auto_display'] == "on") {
		update_option('tt_auto_display', "true");
		$ok = true;
	} else {
		update_option('tt_auto_display', "false");
		$ok = true;
	}
	if ($_REQUEST['tt_small_icon'] == "on") {
		update_option('tt_small_icon', "true");
		$ok = true;
	} else {
		update_option('tt_small_icon', "false");
		$ok = true;
	}
	if ($_REQUEST['tt_add_title'] == "on") {
		update_option('tt_add_title', "true");
		$ok = true;
	} else {
		update_option('tt_add_title', "false");
		$ok = true;
	}
	if ($_REQUEST['tt_limit_to_single'] == "on") {
		update_option('tt_limit_to_single', "true");
		$ok = true;
	} else {
		update_option('tt_limit_to_single', "false");
		$ok = true;
	}
	if ($_REQUEST['tt_url_service']) {
		// Escape this, in case untrusted users can edit options (WPMU).
		$tt_url_service = mysql_real_escape_string($_REQUEST['tt_url_service']);
		if (get_option('tt_url_service') != $tt_url_service) {
			update_option('tt_url_service', $tt_url_service);
			global_flush_tt_cache();
		}
		$ok = true;
	}
	if ($ok) echo '<br /><div id="message" class="updated fade"><p>Tweet This настройки сохранены!</p></div>';
	else echo '<br /><div id="message" class="error fade"><p>Tweet This настройки не могут быть сохранены.</p></div>';
}


// <form> tag is missing action because I don't know the page URL; it varies between WP and WPMU. Browsers know what to do.
function print_tt_form() { ?>
	<p>У Вас <strong><?php
		global $wpdb;
		echo number_format($wpdb->get_var("SELECT COUNT(*)
		FROM $wpdb->posts WHERE post_status = 'publish'"));
	?></strong> опубликованных записей и страниц. Tweet This кэшировал короткие ссылки для <strong><?php
		echo number_format($wpdb->get_var("SELECT COUNT(*) FROM $wpdb->postmeta
		WHERE meta_key = 'tweet_this_url' AND meta_value != 'getnew'"));
	?></strong> из них.</p>	
	<form id="tweet-this" name="tweet-this" method="post">
		<p>URL Сервис:
		<select name="tt_url_service">
		<option value="th8.us"<?php
		if (get_option('tt_url_service') == "th8.us") echo ' selected="selected"';
		?>>Th8.us (16 Символов)</option>
		<option value="is.gd"<?php
		if (get_option('tt_url_service') == "is.gd") echo ' selected="selected"';
		?>>is.gd (17 Символов)</option>
		<option value="urlb.at"<?php
		if (get_option('tt_url_service') == "urlb.at") echo ' selected="selected"';
		?>>urlb.at (18 Символов)</option>
		<option value="bit.ly"<?php
		if (get_option('tt_url_service') == "bit.ly") echo ' selected="selected"';
		?>>bit.ly (20 Символов)</option>
		<option value="snurl"<?php
		if (get_option('tt_url_service') == "snurl") echo ' selected="selected"';
		?>>Snurl.com (22 Символов)</option>
		<option value="tinyurl"<?php
		if (get_option('tt_url_service') == "tinyurl") echo ' selected="selected"';
		?>>TinyURL.com (25 Символов)</option>
		</select></p>
		<p><label><input type="checkbox" name="tt_auto_display"<?php
		if (get_option('tt_auto_display') != "false") echo ' checked="checked"'; ?> /> Автоматически вставлять ссылку Tweet This </label></p>
		<p><label><input type="checkbox" name="tt_small_icon"<?php
		if (get_option('tt_small_icon') == "true") echo ' checked="checked"'; ?> /> Автоматически вставлять маленькую ссылку в конце записи, вместо большой иконки в верхнем правом углу</label></p>
		<p><label><input type="checkbox" name="tt_add_title"<?php
		if (get_option('tt_add_title') != "false") echo ' checked="checked"'; ?> /> Добавить заголовок записи в сообщение twitter</label></p>
		<p><label><input type="checkbox" name="tt_limit_to_single"<?php
		if (get_option('tt_limit_to_single') == "true") echo ' checked="checked"'; ?> /> Показывать ссылку Tweet This только при просмотре записей и страниц</label></p>
	<p class="submit"><input type="submit" name="submit" value="Сохранить настройки" /></p></form>
	<p>Перевод - <a href="http://blogproblog.com">Дмитрий Донченко</a></p>
<?php }


function tweet_this_add_options() {
	if (function_exists('add_options_page')) {
		add_options_page(__('Tweet This Options', 'tweet-this'),
			__('Tweet This', 'tweet-this'), 8,
			__FILE__, 'tweet_this_options');
	}
}


function tweet_this_options() {
	echo '<div class="wrap"><h2>Настройки Tweet This</h2>';
	if ($_POST['submit']) update_tt_options();
	print_tt_form();
	echo '</div>';
}


// Sets one cached URL to "getnew". get_tweet_this_short_url() respawns.
function flush_tt_cache($post_id) {
	$cached_tt_url = get_post_meta($post_id, 'tweet_this_url', true);
	if($cached_tt_url && $cached_tt_url != "getnew") {
	update_post_meta($post_id, 'tweet_this_url', 'getnew');
	}
}


// Deletes the cached URL when you delete one post.
function delete_tt_cache() {
	global $id;
	delete_post_meta($id, 'tweet_this_url');
}


// Sets every cached URL to "getnew". For permalink / URL service changes.
function global_flush_tt_cache() {
	global $wpdb;
	$wpdb->query("UPDATE $wpdb->postmeta
	SET meta_value = 'getnew' WHERE meta_key = 'tweet_this_url'");
}


// Deletes every cached URL. Triggered upon deactivation.
function global_delete_tt_cache() {
	global $wpdb;
	// Careful here.
	$wpdb->query("DELETE FROM $wpdb->postmeta
	WHERE meta_key = 'tweet_this_url'");
}


add_action('admin_menu', 'tweet_this_add_options');
add_action('save_post', 'flush_tt_cache', 1);
add_action('delete_post', 'delete_tt_cache');
add_action('generate_rewrite_rules', 'global_flush_tt_cache');


if (get_option('tt_auto_display') != "false") {
	add_action('wp_head', 'tweet_this_css');
	add_filter('the_content', 'insert_tweet_this');
}


// register_deactivation_hook doesn't exist before WP 2.0.
if (function_exists('register_deactivation_hook'))
	register_deactivation_hook(__FILE__, 'global_delete_tt_cache');

?>